package com.chinaitop.depot.intelligent.grainsituation.model;

import java.math.BigDecimal;
import java.util.Date;

public class TWarningThresholdHistory {
    private String id;

    private String orgId;

    private String vCfCode;

    private String wModule;

    private String wName;

    private BigDecimal wThreshold;

    private BigDecimal threshold;

    private Integer wState;

    private Date wTime;

    private Date wUpdateTime;

    private String dataSource;

    private String wRemark;

    private Date updatetime;

    private String isSend;

    private String wMode;

    private String wWarning;

    /**
     * 检测记录警报历史表id 32位唯一
     * @return id 检测记录警报历史表id 32位唯一
     */
    public String getId() {
        return id;
    }

    /**
     * 检测记录警报历史表id 32位唯一
     * @param id 检测记录警报历史表id 32位唯一
     */
    public void setId(String id) {
        this.id = id == null ? null : id.trim();
    }

    /**
     * 库点编码
     * @return org_id 库点编码
     */
    public String getOrgId() {
        return orgId;
    }

    /**
     * 库点编码
     * @param orgId 库点编码
     */
    public void setOrgId(String orgId) {
        this.orgId = orgId == null ? null : orgId.trim();
    }

    /**
     * 仓房code
     * @return v_cf_code 仓房code
     */
    public String getvCfCode() {
        return vCfCode;
    }

    /**
     * 仓房code
     * @param vCfCode 仓房code
     */
    public void setvCfCode(String vCfCode) {
        this.vCfCode = vCfCode == null ? null : vCfCode.trim();
    }

    /**
     * 报警所属模块
     * @return w_module 报警所属模块
     */
    public String getwModule() {
        return wModule;
    }

    /**
     * 报警所属模块
     * @param wModule 报警所属模块
     */
    public void setwModule(String wModule) {
        this.wModule = wModule == null ? null : wModule.trim();
    }

    /**
     * 模块名称
     * @return w_name 模块名称
     */
    public String getwName() {
        return wName;
    }

    /**
     * 模块名称
     * @param wName 模块名称
     */
    public void setwName(String wName) {
        this.wName = wName == null ? null : wName.trim();
    }

    /**
     * 预警设置值
     * @return w_threshold 预警设置值
     */
    public BigDecimal getwThreshold() {
        return wThreshold;
    }

    /**
     * 预警设置值
     * @param wThreshold 预警设置值
     */
    public void setwThreshold(BigDecimal wThreshold) {
        this.wThreshold = wThreshold;
    }

    /**
     * 检测值
     * @return threshold 检测值
     */
    public BigDecimal getThreshold() {
        return threshold;
    }

    /**
     * 检测值
     * @param threshold 检测值
     */
    public void setThreshold(BigDecimal threshold) {
        this.threshold = threshold;
    }

    /**
     * 处理状态 0.未处理 1.处理中 2.已处理
     * @return w_state 处理状态 0.未处理 1.处理中 2.已处理
     */
    public Integer getwState() {
        return wState;
    }

    /**
     * 处理状态 0.未处理 1.处理中 2.已处理
     * @param wState 处理状态 0.未处理 1.处理中 2.已处理
     */
    public void setwState(Integer wState) {
        this.wState = wState;
    }

    /**
     * 检测时间
     * @return w_time 检测时间
     */
    public Date getwTime() {
        return wTime;
    }

    /**
     * 检测时间
     * @param wTime 检测时间
     */
    public void setwTime(Date wTime) {
        this.wTime = wTime;
    }

    /**
     * 数据更新时间
     * @return w_update_time 数据更新时间
     */
    public Date getwUpdateTime() {
        return wUpdateTime;
    }

    /**
     * 数据更新时间
     * @param wUpdateTime 数据更新时间
     */
    public void setwUpdateTime(Date wUpdateTime) {
        this.wUpdateTime = wUpdateTime;
    }

    /**
     * 
     * @return data_source 
     */
    public String getDataSource() {
        return dataSource;
    }

    /**
     * 
     * @param dataSource 
     */
    public void setDataSource(String dataSource) {
        this.dataSource = dataSource == null ? null : dataSource.trim();
    }

    /**
     * 描述信息
     * @return w_remark 描述信息
     */
    public String getwRemark() {
        return wRemark;
    }

    /**
     * 描述信息
     * @param wRemark 描述信息
     */
    public void setwRemark(String wRemark) {
        this.wRemark = wRemark == null ? null : wRemark.trim();
    }

    /**
     * 
     * @return updatetime 
     */
    public Date getUpdatetime() {
        return updatetime;
    }

    /**
     * 
     * @param updatetime 
     */
    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    /**
     * 是否发送，0发送，1未发送，2发送失败
     * @return is_send 是否发送，0发送，1未发送，2发送失败
     */
    public String getIsSend() {
        return isSend;
    }

    /**
     * 是否发送，0发送，1未发送，2发送失败
     * @param isSend 是否发送，0发送，1未发送，2发送失败
     */
    public void setIsSend(String isSend) {
        this.isSend = isSend == null ? null : isSend.trim();
    }

    /**
     * 模块：0测温，1测虫，2测气
     * @return w_mode 模块：0测温，1测虫，2测气
     */
    public String getwMode() {
        return wMode;
    }

    /**
     * 模块：0测温，1测虫，2测气
     * @param wMode 模块：0测温，1测虫，2测气
     */
    public void setwMode(String wMode) {
        this.wMode = wMode == null ? null : wMode.trim();
    }

    /**
     * 0报警，1预警
     * @return w_warning 0报警，1预警
     */
    public String getwWarning() {
        return wWarning;
    }

    /**
     * 0报警，1预警
     * @param wWarning 0报警，1预警
     */
    public void setwWarning(String wWarning) {
        this.wWarning = wWarning == null ? null : wWarning.trim();
    }
}